summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/drivers/calchase.c
diff options
context:
space:
mode:
author Scott Stone <tafoid@users.noreply.github.com>2014-10-18 20:44:47 +0000
committer Scott Stone <tafoid@users.noreply.github.com>2014-10-18 20:44:47 +0000
commit932b305d754b9c39036a38f418530d7276d936c7 (patch)
tree82cd83a44ddfd6859464d0ebcc71cfca03cd7f9a /src/mame/drivers/calchase.c
parent0a61c69a7712a1d59000d91b2d6e17e0d338fd65 (diff)
calchase.c: [Peter Ferrie]
* Implemented missing DIP switch for Eggs Playing Chicken, promote to working. Press "S" to skip the CMOS error, "S" or wait to skip the emm386.exe error (not an emulation issue), use "Coin 2" to coin-up and start the game, and "1 Player Start" to brake. calchase.c, gamecstl.c, midqslvr.c, queen.c, savquest.c, taitowlf.c, voyager.c, xtom3d.c: [Peter Ferrie] * Intel component is not MXTC, it's MTXC.
Diffstat (limited to 'src/mame/drivers/calchase.c')
-rw-r--r--src/mame/drivers/calchase.c54
1 files changed, 26 insertions, 28 deletions
diff --git a/src/mame/drivers/calchase.c b/src/mame/drivers/calchase.c
index 3491026395e..dc7915afd07 100644
--- a/src/mame/drivers/calchase.c
+++ b/src/mame/drivers/calchase.c
@@ -142,7 +142,7 @@ public:
UINT32 *m_bios_ram;
UINT32 *m_bios_ext_ram;
- UINT8 m_mxtc_config_reg[256];
+ UINT8 m_mtxc_config_reg[256];
UINT8 m_piix4_config_reg[4][256];
UINT32 m_idle_skip_ram;
@@ -166,21 +166,21 @@ public:
required_device<dac_device> m_dac_r;
};
// Intel 82439TX System Controller (MXTC)
// TODO: change with a VIA82C585VPX (North Bridge - APOLLO Chipset)
-static UINT8 mxtc_config_r(device_t *busdevice, device_t *device, int function, int reg)
+static UINT8 mtxc_config_r(device_t *busdevice, device_t *device, int function, int reg)
{
calchase_state *state = busdevice->machine().driver_data<calchase_state>();
-// osd_printf_debug("MXTC: read %d, %02X\n", function, reg);
+// osd_printf_debug("MTXC: read %d, %02X\n", function, reg);
- return state->m_mxtc_config_reg[reg];
+ return state->m_mtxc_config_reg[reg];
}
-static void mxtc_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
+static void mtxc_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
{
calchase_state *state = busdevice->machine().driver_data<calchase_state>();
-// osd_printf_debug("%s:MXTC: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
+// osd_printf_debug("%s:MTXC: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
/*
memory banking with North Bridge:
@@ -204,17 +204,17 @@ static void mxtc_config_w(device_t *busdevice, device_t *device, int function, i
state->membank("bios_ext")->set_base(state->memregion("bios")->base() + 0);
}
- state->m_mxtc_config_reg[reg] = data;
+ state->m_mtxc_config_reg[reg] = data;
}
void calchase_state::intel82439tx_init()
{
- m_mxtc_config_reg[0x60] = 0x02;
- m_mxtc_config_reg[0x61] = 0x02;
- m_mxtc_config_reg[0x62] = 0x02;
- m_mxtc_config_reg[0x63] = 0x02;
- m_mxtc_config_reg[0x64] = 0x02;
- m_mxtc_config_reg[0x65] = 0x02;
+ m_mtxc_config_reg[0x60] = 0x02;
+ m_mtxc_config_reg[0x61] = 0x02;
+ m_mtxc_config_reg[0x62] = 0x02;
+ m_mtxc_config_reg[0x63] = 0x02;
+ m_mtxc_config_reg[0x64] = 0x02;
+ m_mtxc_config_reg[0x65] = 0x02;
}
static UINT32 intel82439tx_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
@@ -226,19 +226,19 @@ static UINT32 intel82439tx_pci_r(device_t *busdevice, device_t *device, int func
if (ACCESSING_BITS_24_31)
{
- r |= mxtc_config_r(busdevice, device, function, reg + 3) << 24;
+ r |= mtxc_config_r(busdevice, device, function, reg + 3) << 24;
}
if (ACCESSING_BITS_16_23)
{
- r |= mxtc_config_r(busdevice, device, function, reg + 2) << 16;
+ r |= mtxc_config_r(busdevice, device, function, reg + 2) << 16;
}
if (ACCESSING_BITS_8_15)
{
- r |= mxtc_config_r(busdevice, device, function, reg + 1) << 8;
+ r |= mtxc_config_r(busdevice, device, function, reg + 1) << 8;
}
if (ACCESSING_BITS_0_7)
{
- r |= mxtc_config_r(busdevice, device, function, reg + 0) << 0;
+ r |= mtxc_config_r(busdevice, device, function, reg + 0) << 0;
}
return r;
}
@@ -247,19 +247,19 @@ static void intel82439tx_pci_w(device_t *busdevice, device_t *device, int functi
{
if (ACCESSING_BITS_24_31)
{
- mxtc_config_w(busdevice, device, function, reg + 3, (data >> 24) & 0xff);
+ mtxc_config_w(busdevice, device, function, reg + 3, (data >> 24) & 0xff);
}
if (ACCESSING_BITS_16_23)
{
- mxtc_config_w(busdevice, device, function, reg + 2, (data >> 16) & 0xff);
+ mtxc_config_w(busdevice, device, function, reg + 2, (data >> 16) & 0xff);
}
if (ACCESSING_BITS_8_15)
{
- mxtc_config_w(busdevice, device, function, reg + 1, (data >> 8) & 0xff);
+ mtxc_config_w(busdevice, device, function, reg + 1, (data >> 8) & 0xff);
}
if (ACCESSING_BITS_0_7)
{
- mxtc_config_w(busdevice, device, function, reg + 0, (data >> 0) & 0xff);
+ mtxc_config_w(busdevice, device, function, reg + 0, (data >> 0) & 0xff);
}
}
@@ -328,7 +328,7 @@ static void intel82371ab_pci_w(device_t *busdevice, device_t *device, int functi
WRITE32_MEMBER(calchase_state::bios_ram_w)
{
- if (m_mxtc_config_reg[0x63] & 0x10) // write to RAM if this region is write-enabled
+ if (m_mtxc_config_reg[0x63] & 0x10) // write to RAM if this region is write-enabled
{
COMBINE_DATA(m_bios_ram + offset);
}
@@ -336,7 +336,7 @@ WRITE32_MEMBER(calchase_state::bios_ram_w)
WRITE32_MEMBER(calchase_state::bios_ext_ram_w)
{
- if (m_mxtc_config_reg[0x63] & 0x40) // write to RAM if this region is write-enabled
+ if (m_mtxc_config_reg[0x63] & 0x40) // write to RAM if this region is write-enabled
{
COMBINE_DATA(m_bios_ext_ram + offset);
}
@@ -571,9 +571,7 @@ static INPUT_PORTS_START( calchase )
PORT_DIPNAME( 0x1000, 0x1000, DEF_STR( Unknown ) )
PORT_DIPSETTING( 0x1000, DEF_STR( Off ) )
PORT_DIPSETTING( 0x0000, DEF_STR( On ) )
- PORT_DIPNAME( 0x2000, 0x2000, DEF_STR( Unknown ) )
- PORT_DIPSETTING( 0x2000, DEF_STR( Off ) )
- PORT_DIPSETTING( 0x0000, DEF_STR( On ) )
+ PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_CUSTOM ) PORT_VBLANK("screen") //eggsplc
PORT_DIPNAME( 0x4000, 0x4000, DEF_STR( Unknown ) )
PORT_DIPSETTING( 0x4000, DEF_STR( Off ) )
PORT_DIPSETTING( 0x0000, DEF_STR( On ) )
@@ -774,4 +772,4 @@ ROM_END
GAME( 1998, hostinv, 0, hostinv, calchase, calchase_state, hostinv, ROT0, "The Game Room", "Host Invaders", GAME_NOT_WORKING|GAME_IMPERFECT_GRAPHICS )
GAME( 1999, calchase, 0, calchase, calchase, calchase_state, calchase, ROT0, "The Game Room", "California Chase", GAME_NOT_WORKING|GAME_IMPERFECT_GRAPHICS )
-GAME( 2002, eggsplc, 0, calchase, calchase, calchase_state, hostinv, ROT0, "The Game Room", "Eggs Playing Chicken", GAME_NOT_WORKING|GAME_IMPERFECT_GRAPHICS )
+GAME( 2002, eggsplc, 0, calchase, calchase, calchase_state, hostinv, ROT0, "The Game Room", "Eggs Playing Chicken", 0 )
@@ -166,21 +166,21 @@ public:
required_device<dac_device> m_dac_r;
};
-// Intel 82439TX System Controller (MXTC)
+// Intel 82439TX System Controller (MTXC)
// TODO: change with a VIA82C585VPX (North Bridge - APOLLO Chipset)